//TextEntryPanel class. This contains a field for text entry and a button
// for executing the action. There is also a caution label.
// Clicking the button or hitting enter in the field will cause a text
// message to be sent to the phone number currently visible in a separate
// JLabel.
//Created by James Vanderhyde, 5 April 2010

import javax.swing.*;
import java.awt.event.*;
import java.awt.BorderLayout;

public class TextEntryPanel extends JPanel
{
    //Field and button for text entry
    private JTextField field;
    private JButton button;
    
    //We store a reference to the phone number label from the 
    // telephone panel so we can get the number when needed.
    private JLabel phoneNumber;
    
    //Constructor.
    // Pass the label containing the phone number as a parameter.
    public TextEntryPanel(JLabel phoneNumberLabel)
    {
        //store the reference
        phoneNumber = phoneNumberLabel;
        
        //create the components
        field = new JTextField(18);
        button = new JButton("Send text");
        field.addActionListener(new TextActionListener());
        button.addActionListener(new TextActionListener());
        
        //set up the panel
        setLayout(new BorderLayout());
        add(field,BorderLayout.WEST);
        add(button,BorderLayout.EAST);
        add(new JLabel("Caution: fees may apply"),BorderLayout.SOUTH);
    }
    
    private class TextActionListener implements ActionListener
    {
        public void actionPerformed(ActionEvent evt)
        {
            //Verify the length of the input
            int length = field.getText().length();
            if (length<=0)
                JOptionPane.showMessageDialog(null,"Message is too short.");
            else if (length>160*4)
                JOptionPane.showMessageDialog(null,"Message is too long.");
            else
            {
                //Use the TextSender class to send a text
                // to the phone number in the label
                int result=TextSender.sendText(phoneNumber.getText(),field.getText());
                if (result>0)
                    JOptionPane.showMessageDialog(null,"Sorry, there was an error trying to send the text.");
            }
        }
    }
}
