//TextSender class. It has one public static method that will send
// an SMS text to an AT&T phone number.
//Created by James Vanderhyde, 3 April 2010

import java.net.URLEncoder;
import java.net.URL;
import java.net.MalformedURLException;
import java.io.*;

public class TextSender
{
    //Returns the URL of the web page that sends the text
    protected static String getBaseURL()
    {
        //This page is served by my home computer. It only works for
        // AT&T numbers. See the project readme file for the PHP code.
        return "http://vanderhyde.us/~james/cs114/sendtextatt.php";
    }
    
    //Sends the specified message as an SMS text to the specified phone number.
    // Returns 0 if all went well.
    public static int sendText(String number, String message)
    {
        //Construct URL from base URL and inputs
        String url = getBaseURL();
        try
        {
            url += "?number="+URLEncoder.encode(number,"UTF-8");
            url += "&message="+URLEncoder.encode(message,"UTF-8");
        }
        catch (UnsupportedEncodingException e)
        {
            System.err.println(e);
        }
        
        //Create a URL object from which we will load a web page
        URL page = null;
        try
        {
            page = new URL(url);
        }
        catch (MalformedURLException e)
        {
            System.err.println(e);
            return 1;
        }
        
        //Load the page (which sends the text) and store the result in a string
        String result=null;
        try
        {
            BufferedReader httpIn = new BufferedReader(new InputStreamReader((InputStream)page.getContent()));
            result=httpIn.readLine();
        }
        catch (IOException e)
        {
            System.err.println(e);
            return 2;
        }
        
        //Check the result
        if (!result.equals("SUCCESS"))
        {
            System.err.println(result);
            return 3;
        }
        return 0;
    }
}
